Module chat_type

Module chat_type 

Minecraft protocol direct chat types.

Structs

ChatDecoration
Controls how one form of a direct chat message is decorated.
ChatType
Describes a direct chat type that a message can be sent with.

Enums

ChatTypeParameter
A value inserted into a chat decoration’s translated message.