pub struct ChatType {
pub chat: ChatDecoration,
pub narration: ChatDecoration,
}Expand description
Describes a direct chat type that a message can be sent with.
The chat decoration is encoded first and the narration decoration second:
ChatDecoration(chat) + ChatDecoration(narration)Both fields use the same decoration structure, but may use different translation keys, parameter orders, and styles.
Examples
use fastnbt::nbt;
use mcproto_types::{
ChatDecoration, ChatType, ChatTypeParameter, Nbt, PrefixedArray,
PrefixedString, TypeCodec,
};
let value = ChatType::new(
ChatDecoration::new(
PrefixedString("chat.type.text".into()),
PrefixedArray(vec![ChatTypeParameter::Sender, ChatTypeParameter::Content]),
Nbt(nbt!({})),
),
ChatDecoration::new(
PrefixedString("chat.type.text.narrate".into()),
PrefixedArray(vec![ChatTypeParameter::Sender, ChatTypeParameter::Content]),
Nbt(nbt!({})),
),
);
let mut encoded = Vec::new();
value.encode(&mut encoded)?;
let mut input = encoded.as_slice();
assert_eq!(ChatType::decode(&mut input)?, value);
assert!(input.is_empty());Fields
chat: ChatDecorationDecoration used for the normal chat presentation.
narration: ChatDecorationDecoration used for narration.
Implementations
Sourceimpl ChatType
impl ChatType
Sourcepub const fn new(chat: ChatDecoration, narration: ChatDecoration) -> Self
pub const fn new(chat: ChatDecoration, narration: ChatDecoration) -> Self
Creates a direct chat type from its chat and narration decorations.