Content

Enum Content 

pub enum Content<V> {
    Text {
        text: String,
    },
    Translatable {
        translate: String,
        fallback: Option<String>,
        with: Vec<Component<V>>,
    },
    Score {
        score: Score,
    },
    Selector {
        selector: String,
        separator: Option<Box<Component<V>>>,
    },
    Keybind {
        keybind: String,
    },
    Nbt {
        nbt: String,
        target: NbtTarget,
        display: NbtDisplay,
        separator: Option<Box<Component<V>>>,
    },
    Object {
        object: ObjectContent,
        fallback: Option<String>,
    },
}
The mutually exclusive content payload of a ComponentObject.

Variants



Text

Literal text.

Fields

text: String

The text to display.



Translatable

Text looked up from a translation key.

Fields

translate: String

The translation key.

fallback: Option<String>

Text used when the translation key is unavailable.

with: Vec<Component<V>>

Components substituted into the translated text.



Score

A value from a scoreboard objective.

Fields

score: Score

The scoreboard holder and objective to query.



Selector

The names selected by an entity selector.

Fields

selector: String

The entity selector expression.

separator: Option<Box<Component<V>>>

Component placed between selected names.



Keybind

The localized name of a client key binding.

Fields

keybind: String

The key-binding identifier.



Nbt

Values read from an NBT path.

Fields

nbt: String

The NBT path to evaluate.

target: NbtTarget

The entity, block, or storage source to query.

display: NbtDisplay

How extracted values are rendered.

separator: Option<Box<Component<V>>>

Component placed between multiple extracted values.



Object

A rendered object such as an atlas sprite or player head.

Fields

object: ObjectContent

The object-specific rendering data.

fallback: Option<String>

Fallback text used when the object cannot be rendered.

Added by Java Edition 26.1.