DebugSubscriptionData

Enum DebugSubscriptionData 

pub enum DebugSubscriptionData {
Show 16 variants DedicatedServerTickTime, Bee(BeeDebugData), VillagerBrain(VillagerBrainDebugData), Breeze(BreezeDebugData), GoalSelector(GoalSelectorDebugData), EntityPath(EntityPathDebugData), EntityBlockIntersection(EntityBlockIntersectionDebugData), BeeHive(BeeHiveDebugData), PointOfInterest(PointOfInterestDebugData), RedstoneWireOrientation(RedstoneWireOrientationDebugData), VillageSection, Raid(RaidDebugData), Structure(StructureDebugData), GameEventListener(GameEventListenerDebugData), NeighborUpdate(NeighborUpdateDebugData), GameEvent(GameEventDebugData),
}
A payload selected by DebugSubscriptionType.

The enum variant determines the discriminator written by DebugSubscriptionEvent and prevents a payload from being paired with the wrong subscription type.

Variants



DedicatedServerTickTime



Bee(BeeDebugData)



VillagerBrain(VillagerBrainDebugData)



Breeze(BreezeDebugData)



GoalSelector(GoalSelectorDebugData)



EntityPath(EntityPathDebugData)



EntityBlockIntersection(EntityBlockIntersectionDebugData)



BeeHive(BeeHiveDebugData)



PointOfInterest(PointOfInterestDebugData)



RedstoneWireOrientation(RedstoneWireOrientationDebugData)



VillageSection



Raid(RaidDebugData)



Structure(StructureDebugData)



GameEventListener(GameEventListenerDebugData)



NeighborUpdate(NeighborUpdateDebugData)



GameEvent(GameEventDebugData)

Implementations

Source

impl DebugSubscriptionData

pub const fn subscription_type(&self) -> DebugSubscriptionType

Returns the discriminator associated with this payload.