EntityMetadataValueType

Enum EntityMetadataValueType 

pub enum EntityMetadataValueType {
Show 43 variants Byte = 0, VarInt = 1, VarLong = 2, Float = 3, String = 4, TextComponent = 5, OptionalTextComponent = 6, Slot = 7, Boolean = 8, Rotations = 9, Position = 10, OptionalPosition = 11, Direction = 12, OptionalLivingEntityReference = 13, BlockState = 14, OptionalBlockState = 15, Particle = 16, Particles = 17, VillagerData = 18, OptionalVarInt = 19, Pose = 20, CatVariant = 21, CatSoundVariant = 22, CowVariant = 23, CowSoundVariant = 24, WolfVariant = 25, WolfSoundVariant = 26, FrogVariant = 27, PigVariant = 28, PigSoundVariant = 29, ChickenVariant = 30, ChickenSoundVariant = 31, ZombieNautilusVariant = 32, OptionalGlobalPosition = 33, PaintingVariant = 34, SnifferState = 35, ArmadilloState = 36, CopperGolemState = 37, WeatheringCopperState = 38, Vector3 = 39, Quaternion = 40, ResolvableProfile = 41, HumanoidArm = 42,
}
Numeric value-type selector used by an entity metadata entry.

Storing this selector separately from a payload is unnecessary and could permit mismatches. EntityMetadataValue is therefore the primary wire value; this enum is exposed for inspection and registry mapping, and is returned by EntityMetadataValue::value_type.

Variants



Byte = 0

The Byte value type (ID 0).



VarInt = 1

The VarInt value type (ID 1).



VarLong = 2

The VarLong value type (ID 2).



Float = 3

The Float value type (ID 3).



String = 4

The String value type (ID 4).



TextComponent = 5

The Text Component value type (ID 5).



OptionalTextComponent = 6

The Optional Text Component value type (ID 6).



Slot = 7

The Slot value type (ID 7).



Boolean = 8

The Boolean value type (ID 8).



Rotations = 9

The Rotations value type (ID 9).



Position = 10

The Position value type (ID 10).



OptionalPosition = 11

The Optional Position value type (ID 11).



Direction = 12

The Direction value type (ID 12).



OptionalLivingEntityReference = 13

The Optional Living Entity Reference value type (ID 13).



BlockState = 14

The Block State value type (ID 14).



OptionalBlockState = 15

The Optional Block State value type (ID 15).



Particle = 16

The Particle value type (ID 16).



Particles = 17

The Particles value type (ID 17).



VillagerData = 18

The Villager Data value type (ID 18).



OptionalVarInt = 19

The Optional VarInt value type (ID 19).



Pose = 20

The Pose value type (ID 20).



CatVariant = 21

The Cat Variant value type (ID 21).



CatSoundVariant = 22

The Cat Sound Variant value type (ID 22).



CowVariant = 23

The Cow Variant value type (ID 23).



CowSoundVariant = 24

The Cow Sound Variant value type (ID 24).



WolfVariant = 25

The Wolf Variant value type (ID 25).



WolfSoundVariant = 26

The Wolf Sound Variant value type (ID 26).



FrogVariant = 27

The Frog Variant value type (ID 27).



PigVariant = 28

The Pig Variant value type (ID 28).



PigSoundVariant = 29

The Pig Sound Variant value type (ID 29).



ChickenVariant = 30

The Chicken Variant value type (ID 30).



ChickenSoundVariant = 31

The Chicken Sound Variant value type (ID 31).



ZombieNautilusVariant = 32

The Zombie Nautilus Variant value type (ID 32).



OptionalGlobalPosition = 33

The Optional Global Position value type (ID 33).



PaintingVariant = 34

The Painting Variant value type (ID 34).



SnifferState = 35

The Sniffer State value type (ID 35).



ArmadilloState = 36

The Armadillo State value type (ID 36).



CopperGolemState = 37

The Copper Golem State value type (ID 37).



WeatheringCopperState = 38

The Weathering Copper State value type (ID 38).



Vector3 = 39

The Vector3 value type (ID 39).



Quaternion = 40

The Quaternion value type (ID 40).



ResolvableProfile = 41

The Resolvable Profile value type (ID 41).



HumanoidArm = 42

The Humanoid Arm value type (ID 42).