pub struct EntityMetadataIndex(/* private fields */);Expand description
A valid entity metadata index in the inclusive range 0..=254.
Byte value 0xff cannot be constructed because it terminates the complete
EntityMetadata sequence.
Implementations
Sourceimpl EntityMetadataIndex
impl EntityMetadataIndex
Sourcepub const TERMINATOR: u8 = 0xff
pub const TERMINATOR: u8 = 0xff
Reserved byte that terminates an entity metadata sequence.
Sourcepub const fn new(index: u8) -> Result<Self, InvalidEntityMetadataIndex>
pub const fn new(index: u8) -> Result<Self, InvalidEntityMetadataIndex>
Creates a valid metadata index.