pub enum HashedSlot {
Empty,
Item(HashedItemStack),
}Expand description
An empty slot or an item stack represented using component data hashes.
A boolean is written first. false represents an empty slot. When it is
true, the item ID and count are followed by a prefixed array of component
type/hash pairs and a prefixed array of removed component types. Array order
is preserved exactly.
Examples
use mcproto_types::{
DataComponentType, HashedDataComponent, HashedItemStack, HashedSlot, Int, TypeCodec,
};
let mut item = HashedItemStack::new(2, 5)?;
item.components_to_add.push(HashedDataComponent {
component_type: DataComponentType::MaxDamage,
data_hash: Int(0x1234_5678),
});
let slot = HashedSlot::Item(item);
let mut encoded = Vec::new();
slot.encode(&mut encoded)?;
let mut input = encoded.as_slice();
assert_eq!(HashedSlot::decode(&mut input)?, slot);See the official Hashed Format protocol documentation.
Variants
Empty
Encoded only as a false presence boolean.
Item(HashedItemStack)
Encoded as true followed by the hashed item-stack fields.