Module text_component

Module text_component 

NBT-backed Minecraft text components.

This module wraps the shared component model for the NBT representation used by the Minecraft protocol.

Structs

TextComponent
A text component encoded as an NBT tag.

Enums

NbtValue
The dynamically typed NBT value used by NbtComponent. Value is a complete NBT value. It owns its data. Compounds and Lists are resursively deserialized. This type takes care to preserve all the information from the original NBT, with the exception of the name of the root compound (which is usually the empty string).