Minecraft protocol types and their wire-codec interface.
The crate models protocol values and provides their encoding and decoding
through TypeCodec and ContextualCodec.
Re-exports
pub use basic::*;pub use chat_type::*;pub use component::*;pub use contextual::*;pub use debug::*;pub use entity_metadata::*;pub use json_text_component::*;pub use lightdata::*;pub use nbt::*;pub use profile::*;pub use recipe::*;pub use slot::*;pub use sound_event::*;pub use teleport_flags::*;pub use text_component::*;
Modules
- basic
- Basic Minecraft protocol types and their wire encodings.
- chat_
type - Minecraft protocol direct chat types.
- component
- Data model for Minecraft text components.
- contextual
- Context and protocol values whose wire representation depends on their enclosing packet or data structure.
- debug
- Debug subscription events, updates, and their typed payloads.
- entity_
metadata - Type-safe entity metadata and particle protocol structures.
- json_
text_ component - JSON-backed Minecraft text components encoded as protocol strings.
- lightdata
- Chunk-section sky and block lighting data.
- nbt
- Named Binary Tag (NBT) values.
- profile
- Minecraft player profiles and resolvable profile references.
- recipe
- Typed recipe protocol structures.
- slot
- Inventory slots, structured data components, and recipe slot displays.
- sound_
event - Minecraft protocol sound event values.
- teleport_
flags - Minecraft protocol teleport flags.
- text_
component - NBT-backed Minecraft text components.
Traits
- Contextual
Codec - Encodes and decodes a value whose wire representation depends on external protocol context.
- Enum
Repr - A numeric protocol type that can represent an enum discriminant.
- Protocol
Enum - Maps a fieldless Rust enum to a numeric Minecraft protocol representation.
- Type
Codec - Encodes and decodes a value with a context-independent wire representation.
Derive Macros
- Protocol
Enum - Re-exports of protocol codec derive macros.
- Type
Struct Codec - Re-exports of protocol codec derive macros.