Crate mcproto_types

Crate mcproto_types 

Minecraft protocol types and their wire-codec interface.

The crate models protocol values and provides their encoding and decoding through TypeCodec and ContextualCodec.

Modules

basic
Basic Minecraft protocol types and their wire encodings.
component
Data model for Minecraft text components.
contextual
Context used by protocol values whose wire representation depends on their enclosing packet or data structure.
json_text_component
JSON-backed Minecraft text components encoded as protocol strings.
nbt
Named Binary Tag (NBT) values.
text_component
NBT-backed Minecraft text components.

Traits

ContextualCodec
Encodes and decodes a value whose wire representation depends on external protocol context.
TypeCodec
Encodes and decodes a value with a context-independent wire representation.