Minecraft protocol direct chat types.
Structs
- Chat
Decoration - Controls how one form of a direct chat message is decorated.
- Chat
Type - Describes a direct chat type that a message can be sent with.
Enums
- Chat
Type Parameter - A value inserted into a chat decoration’s translated message.