pub struct ShapedRecipeGrid { /* private fields */ }Expand description
A width, height, and exactly width * height ingredient displays.
Fields are private so the length invariant cannot be broken after construction. Width, height, and ingredient count are encoded as VarInts.
Implementations
Sourceimpl ShapedRecipeGrid
impl ShapedRecipeGrid
Sourcepub fn new(
width: u32,
height: u32,
ingredients: Vec<SlotDisplay>,
) -> Result<Self, InvalidShapedRecipeGrid>
pub fn new( width: u32, height: u32, ingredients: Vec<SlotDisplay>, ) -> Result<Self, InvalidShapedRecipeGrid>
Creates a grid when its dimensions and ingredient count are valid.
Sourcepub const fn dimensions(&self) -> (u32, u32)
pub const fn dimensions(&self) -> (u32, u32)
Returns the grid dimensions as (width, height).
Sourcepub fn ingredients(&self) -> &[SlotDisplay]
pub fn ingredients(&self) -> &[SlotDisplay]
Returns the ingredient displays in row-major order.
Sourcepub fn into_ingredients(self) -> Vec<SlotDisplay>
pub fn into_ingredients(self) -> Vec<SlotDisplay>
Extracts the ingredient displays in row-major order.