pub enum SlotDisplay {
Empty,
AnyFuel,
WithAnyPotion(WithAnyPotionSlotDisplay),
OnlyWithComponent(OnlyWithComponentSlotDisplay),
Item(ItemSlotDisplay),
ItemStack(ItemStackSlotDisplay),
Tag(TagSlotDisplay),
Dyed(DyedSlotDisplay),
SmithingTrim(SmithingTrimSlotDisplay),
WithRemainder(WithRemainderSlotDisplay),
Composite(CompositeSlotDisplay),
}Expand description
Description of a recipe ingredient slot for use by the client.
The enum variant determines both the registry type ID and the exact payload, so mismatched type IDs and payloads cannot be represented in memory. See the official Slot Display structure documentation.
Examples
use mcproto_types::{
CompositeSlotDisplay, ItemSlotDisplay, PrefixedArray, SlotDisplay, TypeCodec, VarInt,
};
let display = SlotDisplay::Composite(CompositeSlotDisplay {
options: PrefixedArray(vec![
SlotDisplay::AnyFuel,
SlotDisplay::Item(ItemSlotDisplay { item_type_id: VarInt(5) }),
]),
});
let mut encoded = Vec::new();
display.encode(&mut encoded)?;
let mut input = encoded.as_slice();
assert_eq!(SlotDisplay::decode(&mut input)?, display);Variants
Empty
AnyFuel
WithAnyPotion(WithAnyPotionSlotDisplay)
OnlyWithComponent(OnlyWithComponentSlotDisplay)
Item(ItemSlotDisplay)
ItemStack(ItemStackSlotDisplay)
Tag(TagSlotDisplay)
Dyed(DyedSlotDisplay)
SmithingTrim(SmithingTrimSlotDisplay)
WithRemainder(WithRemainderSlotDisplay)
Composite(CompositeSlotDisplay)