Module text_component

Module text_component 

Structs

TextComponent
A network NBT representation of the current Java text component schema.

Enums

NbtValue
Value is a complete NBT value. It owns its data. Compounds and Lists are resursively deserialized. This type takes care to preserve all the information from the original NBT, with the exception of the name of the root compound (which is usually the empty string).